@@ -22,7 +22,8 @@
 # ##############################################################################
 import pickle
 
-from metrics.wallet.analysis import Analysis, find_best_cpu_time_input
+from metrics.wallet.analysis import Analysis, BasicAnalysis, DecisionAnalysis, OptiAnalysis, \
+    find_best_cpu_time_input, export_data_frame
 from autograph.core.enumstyle import *
 
 import pandas as pd
@@ -31,12 +32,8 @@ import jsonpickle.ext.pandas as jsonpickle_pd
 jsonpickle_pd.register_handlers()
 
 
-def import_bin_analysis(str) -> Analysis:
-    return pickle.loads(str)
-
-
-def import_analysis_from_file(filename) -> Analysis:
+def import_analysis_from_file(filename) -> DecisionAnalysis:
     with open(filename, 'rb') as file:
         if filename.split('.')[-1] == 'csv':
-            return Analysis(data_frame=pd.read_csv(file))
-        return pickle.load(file)
+            return DecisionAnalysis(data_frame=pd.read_csv(file))
+        return DecisionAnalysis(data_frame=pickle.load(file))
