@@ -1,7 +1,7 @@
 import os
 from unittest import TestCase
 
-from metrics.wallet import Analysis
+from metrics.wallet import BasicAnalysis
 
 
 class TestReadConfigurationBug(TestCase):
@@ -9,8 +9,8 @@ class TestReadConfigurationBug(TestCase):
         self._example_dir = 'example/'
 
     def test_bug_gitlab_38(self):
-        analysis = Analysis(
+        analysis = BasicAnalysis(
             input_file=os.path.join(self._example_dir, 'issue38/campaign/config/metrics_scalpel.yml'))
-        columns = analysis.campaign_df.data_frame.columns
+        columns = analysis.data_frame.columns
         self.assertTrue('best_bound' in columns)
         self.assertTrue('status' in columns)
